==> akonadi-search-24.05.2.tgz: lib/cmake/KPim6AkonadiSearch/KPim6AkonadiSearchTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KPim6::AkonadiSearchXapian" for configuration "Release"
set_property(TARGET KPim6::AkonadiSearchXapian APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KPim6::AkonadiSearchXapian PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKPim6AkonadiSearchXapian.so.0.0"
  IMPORTED_SONAME_RELEASE "libKPim6AkonadiSearchXapian.so.0.0"
  )

list(APPEND _cmake_import_check_targets KPim6::AkonadiSearchXapian )
list(APPEND _cmake_import_check_files_for_KPim6::AkonadiSearchXapian "${_IMPORT_PREFIX}/lib/libKPim6AkonadiSearchXapian.so.0.0" )

# Import target "KPim6::AkonadiSearchCore" for configuration "Release"
set_property(TARGET KPim6::AkonadiSearchCore APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KPim6::AkonadiSearchCore PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKPim6AkonadiSearchCore.so.0.0"
  IMPORTED_SONAME_RELEASE "libKPim6AkonadiSearchCore.so.0.0"
  )

list(APPEND _cmake_import_check_targets KPim6::AkonadiSearchCore )
list(APPEND _cmake_import_check_files_for_KPim6::AkonadiSearchCore "${_IMPORT_PREFIX}/lib/libKPim6AkonadiSearchCore.so.0.0" )

# Import target "KPim6::AkonadiSearchPIM" for configuration "Release"
set_property(TARGET KPim6::AkonadiSearchPIM APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KPim6::AkonadiSearchPIM PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KPim6::AkonadiCore"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKPim6AkonadiSearchPIM.so.0.0"
  IMPORTED_SONAME_RELEASE "libKPim6AkonadiSearchPIM.so.0.0"
  )

list(APPEND _cmake_import_check_targets KPim6::AkonadiSearchPIM )
list(APPEND _cmake_import_check_files_for_KPim6::AkonadiSearchPIM "${_IMPORT_PREFIX}/lib/libKPim6AkonadiSearchPIM.so.0.0" )

# Import target "KPim6::AkonadiSearchDebug" for configuration "Release"
set_property(TARGET KPim6::AkonadiSearchDebug APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KPim6::AkonadiSearchDebug PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF6::I18n;KPim6::AkonadiCore;KF6::WidgetsAddons;KF6::ConfigCore;KF6::Completion;KF6::ConfigGui"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKPim6AkonadiSearchDebug.so.0.0"
  IMPORTED_SONAME_RELEASE "libKPim6AkonadiSearchDebug.so.0.0"
  )

list(APPEND _cmake_import_check_targets KPim6::AkonadiSearchDebug )
list(APPEND _cmake_import_check_files_for_KPim6::AkonadiSearchDebug "${_IMPORT_PREFIX}/lib/libKPim6AkonadiSearchDebug.so.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> akonadi-search-25.12.1.tgz: lib/cmake/KPim6AkonadiSearch/KPim6AkonadiSearchTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KPim6::AkonadiSearchXapian" for configuration "Release"
set_property(TARGET KPim6::AkonadiSearchXapian APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KPim6::AkonadiSearchXapian PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKPim6AkonadiSearchXapian.so.0.0"
  IMPORTED_SONAME_RELEASE "libKPim6AkonadiSearchXapian.so.0.0"
  )

list(APPEND _cmake_import_check_targets KPim6::AkonadiSearchXapian )
list(APPEND _cmake_import_check_files_for_KPim6::AkonadiSearchXapian "${_IMPORT_PREFIX}/lib/libKPim6AkonadiSearchXapian.so.0.0" )

# Import target "KPim6::AkonadiSearchCore" for configuration "Release"
set_property(TARGET KPim6::AkonadiSearchCore APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KPim6::AkonadiSearchCore PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKPim6AkonadiSearchCore.so.0.0"
  IMPORTED_SONAME_RELEASE "libKPim6AkonadiSearchCore.so.0.0"
  )

list(APPEND _cmake_import_check_targets KPim6::AkonadiSearchCore )
list(APPEND _cmake_import_check_files_for_KPim6::AkonadiSearchCore "${_IMPORT_PREFIX}/lib/libKPim6AkonadiSearchCore.so.0.0" )

# Import target "KPim6::AkonadiSearchPIM" for configuration "Release"
set_property(TARGET KPim6::AkonadiSearchPIM APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KPim6::AkonadiSearchPIM PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KPim6::AkonadiCore"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKPim6AkonadiSearchPIM.so.0.0"
  IMPORTED_SONAME_RELEASE "libKPim6AkonadiSearchPIM.so.0.0"
  )

list(APPEND _cmake_import_check_targets KPim6::AkonadiSearchPIM )
list(APPEND _cmake_import_check_files_for_KPim6::AkonadiSearchPIM "${_IMPORT_PREFIX}/lib/libKPim6AkonadiSearchPIM.so.0.0" )

# Import target "KPim6::AkonadiSearchDebug" for configuration "Release"
set_property(TARGET KPim6::AkonadiSearchDebug APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KPim6::AkonadiSearchDebug PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Widgets;KF6::I18n;KPim6::AkonadiCore;KF6::WidgetsAddons;KF6::ConfigCore;KF6::Completion;KF6::ConfigGui"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKPim6AkonadiSearchDebug.so.0.0"
  IMPORTED_SONAME_RELEASE "libKPim6AkonadiSearchDebug.so.0.0"
  )

list(APPEND _cmake_import_check_targets KPim6::AkonadiSearchDebug )
list(APPEND _cmake_import_check_files_for_KPim6::AkonadiSearchDebug "${_IMPORT_PREFIX}/lib/libKPim6AkonadiSearchDebug.so.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
